@@ -12,8 +12,8 @@
 
 /*  check if only one IFD exists */
 ret_t check_has_only_one_ifd(ctiff_t * ctif) {
-  //printf("check if only one IFD exists\n");
-  tif_rules("only one IFD exists");
+  GET_EMPTY_RET(ret)
+  tifp_check( ctif);
   /* next commented lines, because TIFFNumberOfDirectories are in endless loop,
    * if the TIFF file from https://github.com/EasyinnovaSL/DPFManager/blob/develop/src/test/resources/IFD%20struct/Circular%20E.tif
    */
@@ -21,15 +21,15 @@ ret_t check_has_only_one_ifd(ctiff_t * ctif) {
   uint32 offset = get_ifd0_pos(ctif );
   uint32 IFDn = get_next_ifd_pos( ctif, offset );
   if (0 == IFDn) {
-    ret_t res;
-    res.returnmsg=NULL;
-    res.returncode=0;
-    return res;
+    ret.returncode=is_valid;
+    return ret;
   } else {
     // FIXME: tif_fails?
       char array[TIFFAILSTRLEN];
       snprintf(array, sizeof(array), "baseline TIFF should have only one IFD, but IFD0 at 0x%08x has pointer to IFDn 0x%08x", offset, IFDn );
-      return tif_fails( array);
+      ret = set_value_found_ret (&ret, array);
+      ret.returncode = ifderror_multiple_ifd_detected;
+      return ret;
   }
 }
 /* vim: set tabstop=2 softtabstop=2 shiftwidth=2 smarttab expandtab :*/
